==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/Mtr2.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mtr2:
	"""Mtr2 commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mtr2", core, parent)

	def set(self, mtr_2: enums.NfcMinTr2, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:MTR2 \n
		Sets the minimum value of TR2 supported. \n
			:param mtr_2: TR20| TR21| TR22| TR23
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(mtr_2, enums.NfcMinTr2)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR2 {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcMinTr2:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:MTR2 \n
		Sets the minimum value of TR2 supported. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: mtr_2: TR20| TR21| TR22| TR23"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR2?')
		return Conversions.str_to_scalar_enum(response, enums.NfcMinTr2)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/Mtr2.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mtr2:
	"""Mtr2 commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mtr2", core, parent)

	def set(self, mtr_2: enums.NfcMinTr2, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:MTR2 \n
		Snippet: driver.source.bb.nfc.cblock.mtr2.set(mtr_2 = enums.NfcMinTr2.TR20, channel = repcap.Channel.Default) \n
		Sets the minimum value of TR2 supported. \n
			:param mtr_2: TR20| TR21| TR22| TR23
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(mtr_2, enums.NfcMinTr2)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR2 {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcMinTr2:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:MTR2 \n
		Snippet: value: enums.NfcMinTr2 = driver.source.bb.nfc.cblock.mtr2.get(channel = repcap.Channel.Default) \n
		Sets the minimum value of TR2 supported. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: mtr_2: TR20| TR21| TR22| TR23"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR2?')
		return Conversions.str_to_scalar_enum(response, enums.NfcMinTr2)
